.. _datasets_ref:

Datasets
========

.. automodule:: aeon.datasets
    :no-members:
    :no-inherited-members:

.. currentmodule:: aeon.datasets

.. autosummary::
    :toctree: auto_generated/
    :template: function.rst

    load_airline
    load_arrow_head
    load_gunpoint
    load_osuleaf
    load_italy_power_demand
    load_basic_motions
    load_japanese_vowels
    load_shampoo_sales
    load_longley
    load_lynx
    load_acsf1
    load_uschange
    load_UCR_UEA_dataset
    load_macroeconomic
    load_solar
